@@ -17,7 +17,7 @@ Data::SUID - Generates thread-safe sequential unique ids
 
 =head1 VERSION
 
-version 1.000006
+version 1.000007
 
 =head1 SYNOPSIS
 
@@ -248,7 +248,13 @@ sub suid
 
 =head1 REPOSITORY
 
-L<Data-SUID at GitHub|https://github.com/cpanic/Data-SUID>
+=over 2
+
+=item * L<https://github.com/cpanic/Data-SUID|https://github.com/cpanic/Data-SUID>
+
+=item * L<http://search.cpan.org/dist/Data-SUID/lib/Data/SUID.pm|http://search.cpan.org/dist/Data-SUID/lib/Data/SUID.pm>
+
+=back
 
 =head1 BUG REPORTS
 
